==> BioSAK-1.40.0-py3-none-any.whl: BioSAK/get_MAG_size.py <==
import os
import glob
import argparse
from Bio import SeqIO


get_MAG_size_parser_usage = '''
============= get_MAG_size example commands ============= 

BioSAK get_MAG_size -i refined_MAGs -x fasta 
BioSAK get_MAG_size -i refined_MAGs -x fasta -total

=========================================================
'''


def get_MAG_size(argument_list):

    mag_folder =        argument_list['i']
    mag_extension =     argument_list['x']
    get_total_size =    argument_list['total']

    mag_file_re = '%s/*.%s' % (mag_folder, mag_extension)
    mag_file_list = [os.path.basename(file_name) for file_name in glob.glob(mag_file_re)]

    if len(mag_file_list) == 0:
        print('No file detected, program exited')
        exit()

    all_mag_size = 0
    for each_mag in mag_file_list:
        pwd_mag = '%s/%s' % (mag_folder, each_mag)
        total_len = 0
        for each_seq in SeqIO.parse(pwd_mag, 'fasta'):
            total_len += len(each_seq.seq)
        all_mag_size += total_len
        if get_total_size is False:
            print('%s\t%s\n' % (each_mag, total_len))

    if get_total_size is True:
        get_total_size_Kbp = all_mag_size/1024
        get_total_size_Mbp = all_mag_size/(1024*1024)
        get_total_size_Kbp = float("{0:.2f}".format(get_total_size_Kbp))
        get_total_size_Mbp = float("{0:.2f}".format(get_total_size_Mbp))
        print('Total size: %s Kbp, %s Mbp' % (get_total_size_Kbp, get_total_size_Mbp))


if __name__ == '__main__':

    get_MAG_size_parser = argparse.ArgumentParser()
    get_MAG_size_parser.add_argument('-i',      required=True,                          help='MAG file/folder')
    get_MAG_size_parser.add_argument('-x',      required=False,                         help='file extension')
    get_MAG_size_parser.add_argument('-total',  required=False,  action='store_true',   help='get total size')
    args = vars(get_MAG_size_parser.parse_args())
    get_MAG_size(args)

==> BioSAK-1.40.1-py3-none-any.whl: BioSAK/get_MAG_size.py <==
import os
import glob
import argparse
from Bio import SeqIO


get_MAG_size_parser_usage = '''
============= get_MAG_size example commands ============= 

BioSAK get_MAG_size -i refined_MAGs -x fasta 
BioSAK get_MAG_size -i refined_MAGs -x fasta -total

=========================================================
'''


def get_MAG_size(argument_list):

    mag_folder =        argument_list['i']
    mag_extension =     argument_list['x']
    get_total_size =    argument_list['total']

    mag_file_re = '%s/*.%s' % (mag_folder, mag_extension)
    mag_file_list = [os.path.basename(file_name) for file_name in glob.glob(mag_file_re)]

    if len(mag_file_list) == 0:
        print('No file detected, program exited')
        exit()

    all_mag_size = 0
    for each_mag in mag_file_list:
        pwd_mag = '%s/%s' % (mag_folder, each_mag)
        total_len = 0
        for each_seq in SeqIO.parse(pwd_mag, 'fasta'):
            total_len += len(each_seq.seq)
        all_mag_size += total_len
        if get_total_size is False:
            print('%s\t%s' % (each_mag, total_len))

    if get_total_size is True:
        get_total_size_Kbp = all_mag_size/1024
        get_total_size_Mbp = all_mag_size/(1024*1024)
        get_total_size_Kbp = float("{0:.2f}".format(get_total_size_Kbp))
        get_total_size_Mbp = float("{0:.2f}".format(get_total_size_Mbp))
        print('Number of genome: %s, Total size: %s Kbp, %s Mbp' % (len(mag_file_list), get_total_size_Kbp, get_total_size_Mbp))


if __name__ == '__main__':

    get_MAG_size_parser = argparse.ArgumentParser()
    get_MAG_size_parser.add_argument('-i',      required=True,                          help='MAG file/folder')
    get_MAG_size_parser.add_argument('-x',      required=False,                         help='file extension')
    get_MAG_size_parser.add_argument('-total',  required=False,  action='store_true',   help='get total size')
    args = vars(get_MAG_size_parser.parse_args())
    get_MAG_size(args)
